# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['jageocoder']

package_data = \
{'': ['*']}

install_requires = \
['SQLAlchemy>=2.0.4,<3.0.0',
 'Werkzeug>=2.2.3',
 'deprecated>=1.2.13,<2.0.0',
 'docopt>=0.6.2,<0.7.0',
 'geographiclib>=2.0,<3.0',
 'jaconv>=0.3.4,<0.4.0',
 'marisa-trie>=0.7.8,<0.8.0']

entry_points = \
{'console_scripts': ['jageocoder = jageocoder.__main__:main']}

setup_kwargs = {
    'name': 'jageocoder',
    'version': '1.4.1',
    'description': 'A Japanese-address geocoder for Python.',
    'long_description': '# jageocoder - A Python Japanese geocoder\n\n日本語版は README_ja.md をお読みください。\n\nThis is a Python port of the Japanese-address geocoder used in CSIS at the University of Tokyo\'s ["Address Matching Service"](https://newspat.csis.u-tokyo.ac.jp/geocode/modules/addmatch/index.php?content_id=1) and [GSI Maps](https://maps.gsi.go.jp/).\n\n# Getting Started\n\nThis package provides address-geocoding functionality for Python programs. The basic usage is to specify a dictionary with `init()` then call `search()` to get geocoding results.\n\n```python\npython\n>>> import jageocoder\n>>> jageocoder.init()\n>>> jageocoder.search(\'新宿区西新宿2-8-1\')\n{\'matched\': \'新宿区西新宿2-8-\', \'candidates\': [{\'id\': 5961406, \'name\': \'8番\', \'x\': 139.691778, \'y\': 35.689627, \'level\': 7, \'note\': None, \'fullname\': [\'東京都\', \'新宿区\', \'西新宿\', \'二丁目\', \'8番\']}]}\n```\n\n# How to install\n\n## Prerequisites\n\nRequires Python 3.6.x or later.\n\nThe following packages will be installed automatically.\n\n- [marisa-trie](https://pypi.org/project/marisa-trie/)\n    for building and retrieving TRIE index\n- [SQLAlchemy](https://pypi.org/project/SQLAlchemy/)\n    for abstracting access to the RDBMS\n\n## Install instructions\n\n- Install the package with `pip install jageocoder`\n- Install the dictionary with `install-dictionary` command\n\n```sh\npip install jageocoder\njageocoder install-dictionary\n```\n\nThe dictionary database will be created under\n`{sys.prefix}/jageocoder/db/`, or if the user doesn\'t have \nwrite permission there `{site.USER_DATA}/jageocoder/db/`\nby default.\n\nIf you need to know the location of the directory containing\nthe dictionary database, perform `get-db-dir` command as follows,\nor call `jageocoder.get_db_dir()` in your script.\n\n```sh\njageocoder get-db-dir\n```\n\nIf you prefer to create it in another location, set the environment\nvariable `JAGEOCODER_DB_DIR` before executing `install_dictionary()`\nto specify the directory.\n\n```sh\nexport JAGEOCODER_DB_DIR=\'/usr/local/share/jageocoder/db\'\ninstall-dictionary\n```\n\n## Migrate dictinary\n\nThe `install-dictionary` command will download and install\na version of the address dictionary file that is compatible with\nthe currently installed jageocoder package.\n\nIf you upgrade the jageocoder package after installing\nthe address dictionary file, it may no longer be compatible with\nthe installed address dictionary file.\nIn which case you will need to reinstall or migrate the dictionary.\n\nTo migrate the dictionary, run the `migrate-dictionary` command.\nThis process may take a long time.\n\n```sh\njageocoder migrate-dictionary\n```\n\n## Uninstall instructions\n\nRemove the directory containing the database, or perform \n`uninstall-dictionary` command as follows.\n\n```sh\njageocoder uninstall-dictionary\n```\n\nThen, uninstall the package with `pip` command.\n\n```sh\npip uninstall jageocoder\n```\n\n# How to use\n\n## Use from the command line\n\nWe assume that jageocoder will be embedded in applications\nas a library and used by calling the API, but for testing purposes,\nyou can check the geocoding results with the following command.\n\n```sh\njageocoder search 新宿区西新宿２－８－１\n```\n\nIf you want to look up an address from longitude and latitude,\nspecify `reverse` instead of `search`.\n\n```sh\njageocoder reverse 139.6917 35.6896\n```\n\nYou can check the list of available commands with `--help`.\n\n```sh\njageocoder --help\n```\n\n## Using API\n\nFirst, import jageocoder and initialize it with `init()`.\n\n```\n>>> import jageocoder\n>>> jageocoder.init()\n```\n\n### Search for latitude and longitude by address\n\nUse `search()` to search for the address you want to check the longitude and latitude of.\n\nThe `search()` function returns a dict with `matched` as\nthe matched string and `candidates` as the list of search results.\n(The results are formatted for better viewing)\n\nEach element of `candidates` contains the information of an address node (AddressNode).\n\n```\n>>> jageocoder.search(\'新宿区西新宿２－８－１\')\n{\n  \'matched\': \'新宿区西新宿２－８－\',\n  \'candidates\': [{\n    \'id\': 12299846, \'name\': \'8番\',\n    \'x\': 139.691778, \'y\': 35.689627, \'level\': 7, \'note\': None,\n    \'fullname\': [\'東京都\', \'新宿区\', \'西新宿\', \'二丁目\', \'8番\']\n  }]\n}\n```\n\nThe meaning of the items is as follows\n\n- id: ID in the database\n- name: Address notation\n- x: longitude\n- y: latitude\n- level: Address level (1:Prefecture, 2:County, 3:City and 23 district,\n    4:Ward, 5:Oaza, 6:Aza and Chome, 7:Block, 8:Building)\n- note: Notes such as city codes\n- fullname: List of address notations from the prefecture level to this node\n\n### Search for addresses by longitude and latitude\n\nUse `reverse()` to find addresses by longitude and latitude\n(so called \'reverse geocoding\').\n\nThe `reverse()` function returns the three addresses surrounding\nthe specified longitude and latitude.\n(The results are formatted for better viewing)\n\nThe `candidate` of each element contains information about\nthe address node (AddressNode), and the `dist` contains\nthe distance (geodesic distance, in meters)\nfrom the specified point to the representative point of the address.\n\n```\n>>> jageocoder.reverse(139.6917, 35.6896)\n[\n  {\n    \'candidate\': {\n      \'id\': 12299330, \'name\': \'二丁目\',\n      \'x\': 139.691774, \'y\': 35.68945, \'level\': 6,\n      \'note\': \'postcode:1600023\',\n      \'fullname\': [\'東京都\', \'新宿区\', \'西新宿\', \'二丁目\']\n    },\n    \'dist\': 17.940303970792183\n  }, {\n    \'candidate\': {\n      \'id\': 12300198, \'name\': \'六丁目\',\n      \'x\': 139.690969, \'y\': 35.693426, \'level\': 6,\n      \'note\': \'postcode:1600023\',\n      \'fullname\': [\'東京都\', \'新宿区\', \'西新宿\', \'六丁目\']\n    },\n    \'dist\': 429.6327545403412\n  }, {\n    \'candidate\': {\n      \'id\': 12300498, \'name\': \'四丁目\',\n      \'x\': 139.68762, \'y\': 35.68754, \'level\': 6,\n      \'note\': \'postcode:1600023\',\n      \'fullname\': [\'東京都\', \'新宿区\', \'西新宿\', \'四丁目\']\n    },\n    \'dist\': 434.31591285255234\n  }\n]\n```\n\nIf the `level` optional parameter is specified,\nit will return a more detailed address.\nHowever, it takes time to calculate.\n\n```\n>>> jageocoder.reverse(139.6917, 35.6896, level=7)\n[\n  {\n    \'candidate\': {\n      \'id\': 12299340, \'name\': \'8番\',\n      \'x\': 139.691778, \'y\': 35.689627, \'level\': 7,\n      \'note\': None,\n      \'fullname\': [\'東京都\', \'新宿区\', \'西新宿\', \'二丁目\', \'8番\']\n    },\n    \'dist\': 7.669497303543382\n  }, {\n    \'candidate\': {\n      \'id\': 12299330, \'name\': \'二丁目\',\n      \'x\': 139.691774, \'y\': 35.68945, \'level\': 6,\n      \'note\': \'postcode:1600023\',\n      \'fullname\': [\'東京都\', \'新宿区\', \'西新宿\', \'二丁目\']\n    },\n    \'dist\': 17.940303970792183\n  }, {\n    \'candidate\': {\n      \'id\': 12300588, \'name\': \'15番\',\n      \'x\': 139.688172, \'y\': 35.689264, \'level\': 7,\n      \'note\': None,\n      \'fullname\': [\'東京都\', \'新宿区\', \'西新宿\', \'四丁目\', \'15番\']\n    },\n    \'dist\': 321.50874020809823\n  }\n]\n```\n\n### Explore the attribute information of an address\n\nUse `searchNode()` to retrieve information about an address.\n\nThis function returns a list of type `jageocoder.result.Result` .\nYou can access the address node from node element of the Result object.\n\n```\n>>> results = jageocoder.searchNode(\'新宿区西新宿２－８－１\')\n>>> len(results)\n1\n>>> results[0].matched\n\'新宿区西新宿２－８－\'\n>>> type(results[0].node)\n<class \'jageocoder.node.AddressNode\'>\n>>> node = results[0].node\n>>> node.get_fullname()\n[\'東京都\', \'新宿区\', \'西新宿\', \'二丁目\', \'8番\']\n```\n\n#### Get GeoJSON representation\n\nYou can use the `as_geojson()` method of the Result and AddressNode\nobjects to obtain the GeoJSON representation.\n\n```\n>>> results[0].as_geojson()\n{\'type\': \'Feature\', \'geometry\': {\'type\': \'Point\', \'coordinates\': [139.691778, 35.689627]}, \'properties\': {\'id\': 12299851, \'name\': \'8番\', \'level\': 7, \'note\': None, \'fullname\': [\'東京都\', \'新宿区\', \'西新宿\', \'二丁目\', \'8番\'], \'matched\': \'新宿区西新宿２－８－\'}}\n>>> results[0].node.as_geojson()\n{\'type\': \'Feature\', \'geometry\': {\'type\': \'Point\', \'coordinates\': [139.691778, 35.689627]}, \'properties\': {\'id\': 12299851, \'name\': \'8番\', \'level\': 7, \'note\': None, \'fullname\': [\'東京都\', \'新宿区\', \'西新宿\', \'二丁目\', \'8番\']}}\n```\n\n#### Get the local government codes\n\nThere are two types of local government codes: JISX0402 (5-digit) and\nLocal Government Code (6-digit).\n\nYou can also obtain the prefecture code JISX0401 (2 digits).\n\n```\n>>> node.get_city_jiscode()  # 5-digit code\n\'13104\'\n>>> node.get_city_local_authority_code() # 6-digit code\n\'131041\'\n>>> node.get_pref_jiscode()  # prefecture code\n\'13\'\n```\n\n#### Get link URLs to maps\n\nGenerate URLs to link to GSI and Google maps.\n\n```\n>>> node.get_gsimap_link()\n\'https://maps.gsi.go.jp/#16/35.689627/139.691778/\'\n>>> node.get_googlemap_link()\n\'https://maps.google.com/maps?q=35.689627,139.691778&z=16\'\n```\n\n#### Traverse the parent node\n\nA "parent node" is a node that represents a level above the address.\nGet the node by attribute `parent`.\n\nNow the `node` points to \'8番\', so the parent node will be \'二丁目\'.\n\n```\n>>> parent = node.parent\n>>> parent.get_fullname()\n[\'東京都\', \'新宿区\', \'西新宿\', \'二丁目\']\n>>> parent.x, parent.y\n(139.691774, 35.68945)\n```\n\n#### Traverse the child nodes\n\nA "child node" is a node that represents a level below the address.\nGet the node by attribute `children`.\n\nThere is one parent node, but there are multiple child nodes.\nThe actual return is a SQL query object, but it can be looped through\nwith an iterator or cast to a list.\n\nNow the `parent` points to \'二丁目\', so the child node will be\nthe block number (○番) contained therein.\n\n```\n>>> parent.children\n<sqlalchemy.orm.dynamic.AppenderQuery object at 0x7fbc08404b38>\n>>> [child.name for child in parent.children]\n[\'10番\', \'11番\', \'1番\', \'2番\', \'3番\', \'4番\', \'5番\', \'6番\', \'7番\', \'8番\', \'9番\']\n```\n\n# For developers\n\n## Running the unittests\n\n```sh\npython -m unittest\n``` \n\n`tests.test_search` tests for some special address notations.\n\n- Street address in Sapporo city such as \'北3西1\' for \'北三条西一丁目\'\n- Toorina in Kyoto city such as \'下立売通新町西入薮ノ内町\' for \'薮ノ内町\'\n\n## Create your own dictionary\n\nPlease use the dictionary coverter\n[jageocoder-converter](https://github.com/t-sagara/jageocoder-converter).\n\n## Sample Web Application\n\nA sample of a simple web app using Flask is available under\n`flask-demo`.\n\nPerform the following steps. Then, access port 5000.\n\n```\ncd flask-demo\npip install flask flask-cors\nbash run.sh\n```\n\n## ToDos\n\n- Supporting address changes\n\n    The functionality to handle address changes due to municipal consolidation, etc.\n    has already been implemented in the C++ version, but will be implemented\n    in this package in the future.\n\n## Contributing\n\nAddress notation varies. So suggestions for logic improvements are welcome.\nPlease submit an issue with examples of address notations in use and how they should be parsed.\n\n## Authors\n\n* **Takeshi SAGARA** - [Info-proto Co.,Ltd.](https://www.info-proto.com/)\n\n## License\n\nThis project is licensed under [the MIT License](https://opensource.org/licenses/mit-license.php).\n\nThis is not the scope of the dictionary data license. Please follow the license of the respective dictionary data.\n\n## Acknowledgements\n\nWe would like to thank CSIS for allowing us to provide address matching services\non their institutional website for over 20 years.\n\nWe would also like to thank Professor Asanobu Kitamoto of NII for providing us\nwith a large sample of areas using the older address system and for his many help\nin confirming the results of our analysis.\n',
    'author': 'Takeshi Sagara',
    'author_email': 'sagara@info-proto.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/t-sagara/jageocoder/',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
